Coverage for tictactoe/contest/migrations/0003_latestentry: 100%

# Coverage for tictactoe/contest/migrations/0003_latestentry : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 | # encoding: utf8 from django.db import models, migrations from django.conf import settings class Migration(migrations.Migration): dependencies = [ migrations.swappable_dependency(settings.AUTH_USER_MODEL), ('contest', '0002_fight'), ] operations = [ migrations.CreateModel( name='LatestEntry', fields=[ ('id', models.AutoField(serialize=False, primary_key=True, verbose_name='ID', auto_created=True)), ('user', models.ForeignKey(to_field='id', to=settings.AUTH_USER_MODEL)), ('entry', models.ForeignKey(to_field='id', to='contest.Entry')), ], options={ 'verbose_name_plural': 'Latest Entries', }, bases=(models.Model,), ), ]